<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Web browser was not specified. Visit the configuration section</source>
        <translation>Navigateur  WWW non définit. Selectionnez le navigateur WWW dans la fenêtre de configuration</translation>
    </message>
    <message>
        <source>Could not spawn Web browser process. Check if the Web browser is functional</source>
        <translation>Impossible d&apos;ouvrir le navigateur. Veuillez controler si le navigateur est en fonction.</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Anglais</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation>Italien</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>Polonais</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Allemand</translation>
    </message>
    <message>
        <source>Force running Kadu (not recommended).</source>
        <translation>Activation Kadu malgré tout (non conseillée).</translation>
    </message>
    <message>
        <source>Quit.</source>
        <translation>Abandon.</translation>
    </message>
    <message>
        <source>Please do not run Kadu as a root!
It&apos;s a high security risk!</source>
        <translation>Veuillez demarrer Kadu en root!
Attention danger!
</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Another Kadu is running on this profile but I cannot get its process ID.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smith</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jimbo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yesterday at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dddd at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 weeks ago at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 weeks and %2 days ago at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 weeks and day ago at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>week ago at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>week and day ago at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>week and %2 days ago at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>d MMMM yyyy at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mail client was not specified. Visit the configuration section</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not spawn Mail client process. Check if the Mail client is functional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Look</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Headers and separators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat header separators height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message separators height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove chat header repetitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interval between header removal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove server time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum time difference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat window title syntax</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conference window title prefix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conference window title syntax</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose your language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically checks whether a new version is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WWW browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose your browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Specify path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Konqueror</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mozilla</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mozilla Firefox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dillo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Galeon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Safari</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write specific path to your browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>e-mail client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose your e-mail client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose your email client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KMail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SeaMonkey</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Evolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom e-mail client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write specific path to your email client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow executing commands by parser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debugging mask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gadu-Gadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UIN</source>
        <translation type="unfinished">Numéro de GG</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Servers properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use default servers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IP Addresses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can specify which GG servers to use. Separate every server using semicolon (for example: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port to connect to servers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8074</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>443</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished">Géneral</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show offline contacts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show contacts that are blocked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show contacts which are blocking me</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore messages from anonymous users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore messages from anonymous users also in conferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore richtext from anonymous users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished">Statut</translation>
    </message>
    <message>
        <source>Private status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled, you&apos;re visible only to users on your list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Descirption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On startup, set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose status which will be set on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation>En ligne</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>En ligne avec description</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Je reviens toute suite</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Je reviens toute suite avec description</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Invisible</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Invisible (description.)</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Hors ligne</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Hors ligne ( avec description.)</translation>
    </message>
    <message>
        <source>On startup, set last description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last decription will be set on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On startup, set description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Define description which will be set on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On shutdown, keep current description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current description will be set on shutdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On shutdown, set description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Define description which will be set on shutdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of kept descriptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow using variables in status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Qt style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose icon theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Definie icons paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show status changing button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>My messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>My font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>My nick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User nick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Userbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Descriptions font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font in panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New messages notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Activate windows with new messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flash chat title on new message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show number of new messages on chat title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nice date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose style of chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose emoticons style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Static</source>
        <translation type="unfinished">Statique</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Emoticons theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Emoticons paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Define emoticons paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display group tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Displays group tabs on userbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show available contacts in bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Displays users that are not offline using a bold font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align contact icon to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align icon next to contact name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Column count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of columns displays in userbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tool tip style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose userbox tool-tip style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Descriptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show descriptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Displays descriptions in userbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow multiline descriptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dislpays multiline descriptions in userbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use background image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Define background file for userbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose userbox background style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Centered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show information panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Displays information panel below userbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show vertical scrollbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show vertical scrollbar in information panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show emoticons in panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show emoticons in information panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose information panel style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation type="unfinished">Configuration</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation type="unfinished">Ajoute contact</translation>
    </message>
    <message>
        <source>Manage modules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open chat with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Userlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from userlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search this user in directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show / hide offline users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show / hide users without description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New line / send message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember chat windows positions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open chat window on new message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open chat window when comes new message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open chat window only when I&apos;m online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open chat window on new message only when online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait for message delivery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait for confirmation from server during send messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&apos;Enter&apos; in chat send message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm clearing chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ask before clearing chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save opened windows on exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save opened chat windows when exiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block window close on new message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block chat window when comes new message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max time to block window close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message pruning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically prune chat messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If enabled, messages are pruning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reduce the number of visible messages in chat window to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of visible messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished">Les images</translation>
    </message>
    <message>
        <source>Max image size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum image size that we want to receive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Receive images during invisibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Receiving images during invisibility is allowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit numbers of image recevied per minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Define limit of images received per minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link folding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically fold links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fold links longer than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size,
#{protocol} - protocol that triggered event,
#{event} - name of event,
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opera (new tab)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set invisible if last status was &apos;Offline&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size,
#{message} - message content,
#{backgroundColor} - background color of message,
#{fontColor} - font color of message,
#{nickColor} - font color of nick,
#{sentDate} - when message was sent,
#{receivedDate} - when message was received,
#{separator} - separator between messages,
&lt;kadu:header&gt;text&lt;/kadu:header&gt; - text will not be displayed in &apos;Remove repeated headers&apos; mode
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically start on system startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Displays messages from anonymous users without formatting (colors, images, font weight...) Text is plain black.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display dates is nice format, like Today, Yesterday or Friday</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <source>About</source>
        <translation>A propos de</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Ferme</translation>
    </message>
    <message>
        <source>A&amp;uthors</source>
        <translation>A&amp;uteurs</translation>
    </message>
    <message>
        <source>&amp;Thanks</source>
        <translation>&amp;Remerciements</translation>
    </message>
    <message>
        <source>&amp;ChangeLog</source>
        <translation>&amp;ChangeLog</translation>
    </message>
    <message>
        <source>&amp;License</source>
        <translation>L&amp;icence</translation>
    </message>
</context>
<context>
    <name>ChatManager</name>
    <message>
        <source>%1 sends message</source>
        <translation>Touche %1 envoie le message</translation>
    </message>
    <message>
        <source>Clear messages in chat window</source>
        <translation>Efface la fenêtre du chat</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Insère icône d&apos;emotion</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Insère l&apos;image</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Surligné</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Souligné</translation>
    </message>
    <message>
        <source>Change color</source>
        <translation>Changez la couleur</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Envoie</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Insère l&apos;emotion - Active dans la configuration</translation>
    </message>
    <message>
        <source>&amp;Chat</source>
        <translation>&amp;Discussion</translation>
    </message>
    <message>
        <source>Search this user in directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore user</source>
        <translation>Ignore le contact</translation>
    </message>
    <message>
        <source>Block user</source>
        <translation type="unfinished">Bloques contact</translation>
    </message>
    <message>
        <source>Anonymous users will be unblocked after restarting Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open chat with...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatWidget</name>
    <message>
        <source>Leave conference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation type="unfinished">Insère l&apos;image</translation>
    </message>
    <message>
        <source>This file is not readable</source>
        <translation type="unfinished">Fichier illisible</translation>
    </message>
    <message>
        <source>This file is too big (%1 &gt;= %2)</source>
        <translation type="unfinished">Fichier trop gros (%1 &gt;= %2)</translation>
    </message>
    <message>
        <source>This file is too big for %1.
Do you really want to send this image?
</source>
        <translation type="unfinished">Le volume de ce fichier est trop gros pour %1.
Souhaitez vous vraiment expédier cette image?</translation>
    </message>
    <message>
        <source>This file is too big for %1 of %2 contacts.
Do you really want to send this image?
Some of them probably will not get it.</source>
        <translation type="unfinished">Ce fichier est trop volumineux pour  %1 z %2 contacts.
Souhaitez vous vraiment expédier cette image?
Probablement il ne sera pas delivré.</translation>
    </message>
    <message>
        <source>Conference with </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat with </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat window will be cleared. Continue?</source>
        <translation type="unfinished">La fenêtre du message sera effacée. Voulez vous continuer?</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Envoie</translation>
    </message>
    <message>
        <source>Cannot send message while being offline.</source>
        <translation type="unfinished">Ne peut pas envoyer le message tout en étant hors ligne.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annule</translation>
    </message>
    <message>
        <source>All messages received in this conference will be ignored
from now on. Are you sure you want to leave this conference?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatWindow</name>
    <message>
        <source>New message received, close window anyway?</source>
        <translation type="unfinished">Nouvel message reçu, voulez vous fermer la fenêtre?</translation>
    </message>
</context>
<context>
    <name>ChooseDescription</name>
    <message>
        <source>Select description</source>
        <translation>Selectionnez la description</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annule</translation>
    </message>
</context>
<context>
    <name>ConfigurationWindow</name>
    <message>
        <source>Ok</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Appliquez</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annule</translation>
    </message>
</context>
<context>
    <name>CustomInput</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GaduFormater</name>
    <message>
        <source>###IMAGE BLOCKED###</source>
        <translation type="unfinished">###IMAGE BLOQUÉ###</translation>
    </message>
    <message>
        <source>###IMAGE TOO BIG###</source>
        <translation type="unfinished">###CETTE IMAGE A TROP DE POIDS###</translation>
    </message>
</context>
<context>
    <name>GaduProtocol</name>
    <message>
        <source>I am busy.</source>
        <translation>Je suis occupé.</translation>
    </message>
    <message>
        <source>Unable to connect, server has not been found</source>
        <translation>Communication impossible, serveur introuvable</translation>
    </message>
    <message>
        <source>Unable to connect</source>
        <translation>Connexion impossible</translation>
    </message>
    <message>
        <source>Unable to connect, server has returned unknown data</source>
        <translation>Connexion impossible, serveur reponds données inconnues</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during reading</source>
        <translation>Connexion impossible, interrompue lors de la lecture</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during writing</source>
        <translation>Connexion impossible, interrompue lors de l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Unable to connect, incorrect password</source>
        <translation>Connexion impossible, mot de passe incorrect</translation>
    </message>
    <message>
        <source>Unable to connect, error of negotiation TLS</source>
        <translation>Connexion impossible, erreur négotiation TLS</translation>
    </message>
    <message>
        <source>Connection timeout!</source>
        <translation>Temps de connexion depassé!
</translation>
    </message>
    <message>
        <source>Disconnection has occured</source>
        <translation>Connexion interrompue</translation>
    </message>
    <message>
        <source>UIN or password not set!</source>
        <translation>UIN ou mot de passe non enregistrés!</translation>
    </message>
    <message>
        <source>Please change your email in &quot;Change password / email&quot; window. Leave new password field blank.</source>
        <translation>Change votre adresse e-Mail dans la fenêtre &quot;Change mot de passe / e-Mail&quot;. Le champs de mot de passe nouveau vide.</translation>
    </message>
    <message>
        <source>Unable to connect, servers are down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection will be stopped
Your password is incorrect!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Too many connection attempts with bad password!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection will be stopped
Too many attempts with bad password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filtered message too long (%1&gt;=%2)</source>
        <translation type="unfinished">Le message filtré trop long (%1&gt;=%2)</translation>
    </message>
    <message>
        <source>Message blocked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Messagebox full.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message not delivered.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GroupsManager</name>
    <message>
        <source>All</source>
        <translation>Tous</translation>
    </message>
</context>
<context>
    <name>Ignored</name>
    <message>
        <source>Manage ignored users</source>
        <translation>Liste des utilisateurs ignorés</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Efface</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajoute</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>VIN</translation>
    </message>
    <message>
        <source>This dialog box allows you to manage your ignored contacts.</source>
        <translation>Cette fenêtre de dialogue permet d&apos;ajouter et effacer les contacts, ceux qui doivent être ignorés.</translation>
    </message>
    <message>
        <source>Type here the UIN of the person you want to ignore.</source>
        <translation>Veuillez indiquer le numéro VIN de GG , de la personne qui doit être ignorée.</translation>
    </message>
    <message>
        <source>Uin:</source>
        <translation>Numéro de GG VIN:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermes</translation>
    </message>
</context>
<context>
    <name>ImageDialog</name>
    <message>
        <source>Images</source>
        <translation>Les images</translation>
    </message>
</context>
<context>
    <name>Kadu</name>
    <message>
        <source>Configuration</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Ajoute contact</translation>
    </message>
    <message>
        <source>Kadu: %1</source>
        <translation>Kadu: %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Hors ligne</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Sortir de  Kadu</translation>
    </message>
    <message>
        <source>Notify about user</source>
        <translation>Renseigne sur le contact</translation>
    </message>
    <message>
        <source>Offline to user</source>
        <translation>Indisponible pour ce contact</translation>
    </message>
    <message>
        <source>Manage &amp;ignored</source>
        <translation>Administre les &amp;ignore</translation>
    </message>
    <message>
        <source>Personal information</source>
        <translation>Données personnelles</translation>
    </message>
    <message>
        <source>H&amp;elp</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>A&amp;bout...</source>
        <translation>&amp;Informations concernant le programme...</translation>
    </message>
    <message>
        <source>&amp;Hide Kadu</source>
        <translation>&amp;Cache Kadu</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Uniquement pour les amis</translation>
    </message>
    <message>
        <source>I&amp;mport / Export userlist</source>
        <translation>I&amp;mport / eksport liste de contacts</translation>
    </message>
    <message>
        <source>Selected users:
%0will be deleted. Are you sure?</source>
        <translation>Les contacts choisis:
%0serons effacés.Veuillez confirmer?</translation>
    </message>
    <message>
        <source>Hide description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search user in directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy personal info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contact: %a[ (%u)]
[First name: %f
][Last name: %r
][Mobile: %m
]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open description link in browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write email message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search in directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Efface</translation>
    </message>
    <message>
        <source>Hide offline users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show offline users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide users without description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show users without description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only online and description users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show all users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent chats...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No closed chats found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contact data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Me</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished">En ligne</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation type="unfinished">En ligne avec description</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation type="unfinished">Je reviens toute suite</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation type="unfinished">Je reviens toute suite avec description</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="unfinished">Invisible</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation type="unfinished">Invisible (description.)</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation type="unfinished">Hors ligne ( avec description.)</translation>
    </message>
</context>
<context>
    <name>KaduMainWindow</name>
    <message>
        <source>Create new toolbar</source>
        <translation type="unfinished">Créez un nouveau barre d&apos;outil</translation>
    </message>
</context>
<context>
    <name>KaduTabBar</name>
    <message>
        <source>Add new group</source>
        <translation>Ajoute nouvel groupe de contacts</translation>
    </message>
    <message>
        <source>Name of new group:</source>
        <translation>Nom de nouvel groupe: </translation>
    </message>
    <message>
        <source>Add to group %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to group %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KaduTextBrowser</name>
    <message>
        <source>Save image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File already exists. Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot save image: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainConfigurationWindow</name>
    <message>
        <source>None</source>
        <translation type="unfinished">Sans icône d&apos;emotion</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advenced chat&apos;s look configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message from Your friend</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageBox</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Oui</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Non</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annule</translation>
    </message>
</context>
<context>
    <name>ModulesDialog</name>
    <message>
        <source>Manage Modules</source>
        <translation>Administres les modules</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Static</source>
        <translation>Statique</translation>
    </message>
    <message>
        <source>Loaded</source>
        <translation>Chargé</translation>
    </message>
    <message>
        <source>Module name</source>
        <translation>Nom de module</translation>
    </message>
    <message>
        <source>Module type</source>
        <translation>Type de module</translation>
    </message>
    <message>
        <source>State</source>
        <translation>État</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermes</translation>
    </message>
    <message>
        <source>Dynamic</source>
        <translation>Dynamique</translation>
    </message>
    <message>
        <source>Not loaded</source>
        <translation>Non chargé</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>&lt;b&gt;Module:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Depends on:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Conflicts with:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Provides:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Author:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Version:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Description:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Module :&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Dépend de :&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Conflits avec :&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Fournit :&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Auteur :&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Version :&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Description :&lt;/b&gt;&lt;b&gt;&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Hide base modules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Module: &lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Depends on: &lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Conflicts with: &lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Provides: &lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Author: &lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Version: &lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Description: &lt;/b&gt;%7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption.
You can load (or unload) them by double-clicking on their names.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModulesManager</name>
    <message>
        <source>&amp;Manage Modules</source>
        <translation>A&amp;dministration des modules</translation>
    </message>
    <message>
        <source>Required module %1 was not found</source>
        <translation>Module recherché %1 non trouvé</translation>
    </message>
    <message>
        <source>Module %1 is already active</source>
        <translation>Module%1 déjà actif</translation>
    </message>
    <message>
        <source>Cannot load %1 module library.:
%2</source>
        <translation>Je n&apos;arrive pas à charger le module de la bibliothèque %1:
%2</translation>
    </message>
    <message>
        <source>Module %1 cannot be deactivated because it is used now</source>
        <translation>Module %1 impossible à activer car actuellement utilisé</translation>
    </message>
    <message>
        <source>Module %1 conflicts with: %2</source>
        <translation>Module %1 Conflit avec: %2</translation>
    </message>
    <message>
        <source>Cannot find required functions in module %1.
Maybe it&apos;s not Kadu-compatible Module.</source>
        <translation>Pas trouvé les fonctions nécessaires dans le module %1.
Peut être module incompatible avec Kadu.</translation>
    </message>
    <message>
        <source>Module initialization routine for %1 failed.</source>
        <translation>Initiation de module pour %1 échouée.</translation>
    </message>
</context>
<context>
    <name>OpenChatWith</name>
    <message>
        <source>Open chat with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Userlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UIN or nick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annule</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
</context>
<context>
    <name>PathListEdit</name>
    <message>
        <source>Select</source>
        <translation type="unfinished">Choisir</translation>
    </message>
</context>
<context>
    <name>PathListEditWindow</name>
    <message>
        <source>Select paths</source>
        <translation type="unfinished">Selectionne le chemin</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">Ajoute</translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished">Change</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Efface</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annule</translation>
    </message>
    <message>
        <source>Choose a directory</source>
        <translation type="unfinished">Selectionne le catalogue</translation>
    </message>
</context>
<context>
    <name>PersonalInfoDialog</name>
    <message>
        <source>Personal Information</source>
        <translation>Données personnelles</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudo</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Genre</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Homme</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Femme</translation>
    </message>
    <message>
        <source>Birthyear</source>
        <translation>Date de naissance</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Ville</translation>
    </message>
    <message>
        <source>Family Name</source>
        <translation>Nom de famille</translation>
    </message>
    <message>
        <source>Family City</source>
        <translation>Ville d&apos;origine</translation>
    </message>
    <message>
        <source>This dialog box allows you to manage your personal information, for example your name, surname or age.</source>
        <translation>Cette fenêtre de dialogue permet d&apos;administrer les données personnelles comme: prénom, nom, age, genre.</translation>
    </message>
    <message>
        <source>Your personal information</source>
        <translation>Vos données personnelles</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Enregistre</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Recharge</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Ferme</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Cherche</translation>
    </message>
    <message>
        <source>&amp;Next results</source>
        <translation>&amp;Résultat suivant</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudo</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Genre</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Homme</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Femme</translation>
    </message>
    <message>
        <source>Birthyear</source>
        <translation>Année de naissance</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Ville</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>Numéro GG</translation>
    </message>
    <message>
        <source>Search criteria</source>
        <translation>Critères de recherche</translation>
    </message>
    <message>
        <source>&amp;Personal data</source>
        <translation>&amp;Données personnelles</translation>
    </message>
    <message>
        <source>Search using the personal data typed above (name, nickname)...</source>
        <translation>Cherche en utilisant les données personnelles inscrites plus haut(nom, pseudo)...</translation>
    </message>
    <message>
        <source>&amp;Uin number</source>
        <translation>&amp;Numéro GG</translation>
    </message>
    <message>
        <source>Search for this UIN exclusively</source>
        <translation>Cherche ce numéro VIN de GG</translation>
    </message>
    <message>
        <source>Only active users</source>
        <translation>Seulement les utilisateurs actifs</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Birth year</source>
        <translation>Année de naissance</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>Recherche...</translation>
    </message>
    <message>
        <source>Done searching</source>
        <translation>Recherche terminée</translation>
    </message>
    <message>
        <source>from</source>
        <translation>de</translation>
    </message>
    <message>
        <source>to</source>
        <translation>à</translation>
    </message>
    <message>
        <source>There were no results of your search</source>
        <translation>Pas de résultat de recherche</translation>
    </message>
    <message>
        <source>Search user in directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add selected user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Chat</source>
        <translation type="unfinished">&amp;Discussion</translation>
    </message>
    <message>
        <source>Cannot search contacts in offline mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectFile</name>
    <message>
        <source>Insert image</source>
        <translation type="unfinished">Insère l&apos;image</translation>
    </message>
    <message>
        <source>Select File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select audio File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectFont</name>
    <message>
        <source>Select</source>
        <translation>Choisir</translation>
    </message>
</context>
<context>
    <name>SyntaxEditor</name>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Efface</translation>
    </message>
    <message>
        <source>Unable to remove syntax: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyntaxEditorWindow</name>
    <message>
        <source>Kadu syntax editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annule</translation>
    </message>
    <message>
        <source>New syntax name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter new syntax name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syntax %1 already exists and cannot be modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overwrite %1 syntax?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TokenDialog</name>
    <message>
        <source>Read this code ...</source>
        <translation>Lisez ce code ...</translation>
    </message>
    <message>
        <source>and type here</source>
        <translation>et inscrivez le ici</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annule</translation>
    </message>
</context>
<context>
    <name>ToolBar</name>
    <message>
        <source>Delete toolbar</source>
        <translation>Veuillez effacer le barre d&apos;outil</translation>
    </message>
    <message>
        <source>Add new button</source>
        <translation>Ajoutez le nouveau bouton</translation>
    </message>
    <message>
        <source>Remove toolbar?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No items to add found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show text label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete button</source>
        <translation type="unfinished">Effassez le bouton</translation>
    </message>
    <message>
        <source>Create new toolbar</source>
        <translation type="unfinished">Créez un nouveau barre d&apos;outil</translation>
    </message>
    <message>
        <source>Block toolbars</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Updates</name>
    <message>
        <source>The newest Kadu version is %1</source>
        <translation>La nouvelle version de Kadu est %1</translation>
    </message>
</context>
<context>
    <name>UserBox</name>
    <message>
        <source>Hide descriptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show descriptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nicks, case insensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nicks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User management</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserInfo</name>
    <message>
        <source>User info on %1</source>
        <translation>Information concernant l&apos;utilisateur %1</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>Numéro GG</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudo</translation>
    </message>
    <message>
        <source>AltNick</source>
        <translation>Montres pseudo </translation>
    </message>
    <message>
        <source>First name</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Mobile</source>
        <translation>Téléphone mobile</translation>
    </message>
    <message>
        <source>Address IP and Port</source>
        <translation>Adresse IP et port</translation>
    </message>
    <message>
        <source>Protocol version</source>
        <translation>Version de protocole</translation>
    </message>
    <message>
        <source>DNS name</source>
        <translation>Nom DNS</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>(Unknown)</source>
        <translation>(Inconnu)</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Géneral</translation>
    </message>
    <message>
        <source>Block user</source>
        <translation>Bloques contact</translation>
    </message>
    <message>
        <source>Offline to user</source>
        <translation>Hors ligne pour ce contact</translation>
    </message>
    <message>
        <source>Notify about status changes</source>
        <translation>Renseigne sur le changement de statut</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Autres</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Ajoute contact</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajoute</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Réactualise</translation>
    </message>
    <message>
        <source>Altnick field cannot be empty.</source>
        <translation>La zone d&apos;Altnick ne peut pas être vide.</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Ferme</translation>
    </message>
    <message>
        <source>This dialog box allows you to view and edit information about the selected contact.</source>
        <translation>Cette fenêtre de dialogue permet de rediger les informations concernant le contact sellectionné.</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Groupes</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>Ajoute un nouveau groupe</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is prohibited</source>
        <translation>&apos;%1&apos; est interdit</translation>
    </message>
    <message>
        <source>This group already exists!</source>
        <translation>Ce groupe existe déjà!</translation>
    </message>
    <message>
        <source>Numbers are prohibited</source>
        <translation>Les numéros sont interdit</translation>
    </message>
    <message>
        <source>Change icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose an icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User known as %1 with that UIN is already in userlist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation>En ligne</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>En ligne avec description</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Je reviens toute suite</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Je reviens toute suite avec description</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Invisible</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Invisible (description.)</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Hors ligne</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Hors ligne ( avec description.)</translation>
    </message>
</context>
<context>
    <name>UserStatus</name>
    <message>
        <source>Online</source>
        <translation>En ligne</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>En ligne avec description</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Je reviens toute suite</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Je reviens toute suite avec description</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Invisible</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Invisible (description.)</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Hors ligne</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Hors ligne ( avec description.)</translation>
    </message>
    <message>
        <source>Blocking</source>
        <translation>Blockage</translation>
    </message>
</context>
<context>
    <name>UserlistImportExport</name>
    <message>
        <source>Import / export userlist</source>
        <translation>Import / eksport liste de contacts</translation>
    </message>
    <message>
        <source>This dialog box allows you to import and export your buddy list to a server or a file.</source>
        <translation>Cette zone de dialogue vous permet d&apos;importer et exporter votre liste des contacts vers un serveur ou un fichier GG et aussi avec /dans le fichier.</translation>
    </message>
    <message>
        <source>Import userlist</source>
        <translation>Import liste de contacts</translation>
    </message>
    <message>
        <source>UIN</source>
        <translation>Numéro de GG</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudo</translation>
    </message>
    <message>
        <source>Disp. nick</source>
        <translation>Montres</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <source>Mobile no.</source>
        <translation>Nr de téléphone</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Groupe</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>&amp;Fetch userlist</source>
        <translation>&amp;Import liste de contacts</translation>
    </message>
    <message>
        <source>&amp;Import from file</source>
        <translation>&amp;Import à partir de fichier</translation>
    </message>
    <message>
        <source>&amp;Save results</source>
        <translation>&amp;Enregistre les résultats</translation>
    </message>
    <message>
        <source>&amp;Merge results</source>
        <translation>&amp;Fusionnes les résultats</translation>
    </message>
    <message>
        <source>Export userlist</source>
        <translation>Export liste de contacts</translation>
    </message>
    <message>
        <source>%1 entries will be exported</source>
        <translation> %1 Exportation des entrées</translation>
    </message>
    <message>
        <source>Se&amp;nd userlist</source>
        <translation>En&amp;voie la liste des utilisateurs</translation>
    </message>
    <message>
        <source>&amp;Delete userlist</source>
        <translation>&amp;Efface la liste des utilisateurs</translation>
    </message>
    <message>
        <source>&amp;Export to file</source>
        <translation>&amp;Export dans le fichier</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Ferme</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The import userlist from file was unsuccessful</source>
        <translation>Importation de la liste terminée avec l&apos;erreur interne
Importation à partir du fichier non réussie</translation>
    </message>
    <message>
        <source>Your userlist has been successfully exported to file</source>
        <translation>Liste de contacts a été exportée avec success dans le fichier</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The export userlist to file was unsuccessful</source>
        <translation>Application a rencontré un erreur interne
Export liste de contacts dans le fichier non reussi.</translation>
    </message>
    <message>
        <source>Your userlist has been successfully exported to server</source>
        <translation>Exportation de la liste de conacts sur serveur reussie</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The export was unsuccessful</source>
        <translation>Erreur interne
Exportation de la liste de contact sur le serveur non reussie</translation>
    </message>
    <message>
        <source>Your userlist has been successfully deleted on server</source>
        <translation>Liste de contact effacée du serveur</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The delete userlist on server was unsuccessful</source>
        <translation>Application erreur interne
Effacement de la liste de contacts du seveur non reussi</translation>
    </message>
    <message>
        <source>Cannot import user list from server in offline mode</source>
        <translation>Impossible d&apos;importer la liste de contacts du serveur sans connexion</translation>
    </message>
    <message>
        <source>This operation will delete your current user list. Are you sure you want this?</source>
        <translation>Cette opération va effacer ta liste actuelle de contacts. Veuillez confirmer votre accord?</translation>
    </message>
    <message>
        <source>Cannot export user list to server in offline mode</source>
        <translation>Impossible d&apos;exporter la liste de contacts sur le serveur sans connection</translation>
    </message>
    <message>
        <source>Cannot clear user list on server in offline mode</source>
        <translation>Impossible d&apos;effacer la liste de contacts du serveur sans connection</translation>
    </message>
    <message>
        <source>File exists. Are you sure you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
